package com.huiju.estateagents.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.entity.TaActivityDynamicEnlist;
import com.huiju.estateagents.entity.TaBuildingDynamic;
import com.huiju.estateagents.mapper.TaActivityDynamicEnlistMapper;
import com.huiju.estateagents.service.ITaBuildingDynamicService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.web.bind.ServletRequestDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import javax.swing.*;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * <p>
 * 项目动态表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@RestController
@RequestMapping("/api")
public class TaBuildingDynamicController extends BaseController {

    @Autowired
    private ITaBuildingDynamicService iBuildingDynamicService;

    @InitBinder
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }

    @RequestMapping(value = "/admin/iBuildingDynamicList", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicList(@RequestParam("pageNum")Integer pageNum,
                                             @RequestParam("pageSize")Integer pageSize,
                                             @RequestParam(required = false)String name ,
                                             @RequestParam(required = false)String buildingId,
                                             HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicList(pageNum,pageSize,name,buildingId);
        return responseBean;
    }

    @RequestMapping(value = "/admin/iBuildingDynamicSelectId/{id}", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicSelectId(@PathVariable(value = "id") String id, HttpSession session){
        ResponseBean  responseBean = iBuildingDynamicService.iBuildingDynamicSelectId(id);
        return responseBean;
    }

    /**
     * 活动列表
     * @param pageNum
     * @param pageSize
     * @param request
     * @return
     */
    @RequestMapping(value = "/wx/buildingDynamiceList", method = RequestMethod.GET)
    public ResponseBean wxBuildingDynamiceList(@RequestParam(value = "buildingId")String buildingId,
                                               @RequestParam(value = "pageNum",defaultValue = "1")Integer pageNum,
                                               @RequestParam(value = "pageSize",defaultValue = "10")Integer pageSize,
                                               HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        ResponseBean  responseBean = iBuildingDynamicService.getWxBuildingDynamiceList(pageNum,pageSize,buildingId,openid);
        return responseBean;
    }

    /**
     * 活动详情
     * @param dynamicId
     * @param buildingId
     * @return
     */
    @RequestMapping(value = "/wx/buildingDynamiceInfo/{dynamicId}", method = RequestMethod.GET)
    public ResponseBean iBuildingDynamicInfo(@PathVariable(value = "dynamicId") String dynamicId,
                                             @RequestParam("buildingId")String buildingId,
                                             HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        ResponseBean  responseBean = iBuildingDynamicService.getWxBuildingDynamiceInfo(dynamicId,buildingId,openid);
        return responseBean;
    }

    /**
     * 添加活动报名
     * @param taActivityDynamicEnlist
     * @param request
     * @return
     */
    @RequestMapping(value = "/wx/activityDynamicEnlistAdd", method = RequestMethod.POST)
    public ResponseBean taActivityDynamicEnlist(@RequestBody TaActivityDynamicEnlist taActivityDynamicEnlist,
                                                HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        ResponseBean  responseBean = iBuildingDynamicService.taActivityDynamicEnlistAdd(taActivityDynamicEnlist);
        return responseBean;
    }


    @RequestMapping(value = "/admin/buildingDynamic/add" ,method =RequestMethod.POST)
    public  ResponseBean buildingDynamicAdd(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        TaBuildingDynamic dynamic = JSONObject.parseObject(parameter, TaBuildingDynamic.class);
        dynamic.setStatus(0);
//        dynamic.setDynamicId(idGen.nextId()+"");
        dynamic.setCreateDate(LocalDateTime.now());
        iBuildingDynamicService.save(dynamic);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/update" ,method =RequestMethod.PUT)
    public  ResponseBean buildingDynamicUpdate(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        TaBuildingDynamic dynamic = JSONObject.parseObject(parameter, TaBuildingDynamic.class);
        QueryWrapper<TaBuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("dynamic_id", dynamic.getDynamicId());
        iBuildingDynamicService.update(dynamic, buildingDynamicQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/delete", method = RequestMethod.DELETE)
    public ResponseBean pageImdelect(@RequestParam(value = "id",required = false)String id) {
        ResponseBean responseBean = iBuildingDynamicService.buildingDynamicDelete(id);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/send/{dynamicId}", method = RequestMethod.PUT)
    public ResponseBean send(@PathVariable String dynamicId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<TaBuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id", dynamicId);
        TaBuildingDynamic dynamic = iBuildingDynamicService.getOne(dynamicQueryWrapper);
        dynamic.setStatus(1);
        dynamic.setPublishDate(LocalDateTime.now());
        iBuildingDynamicService.update(dynamic, dynamicQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/admin/buildingDynamic/cancel/{dynamicId}", method = RequestMethod.PUT)
    public ResponseBean cancel(@PathVariable String dynamicId) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<TaBuildingDynamic> dynamicQueryWrapper = new QueryWrapper<>();
        dynamicQueryWrapper.eq("dynamic_id", dynamicId);
        TaBuildingDynamic dynamic = iBuildingDynamicService.getOne(dynamicQueryWrapper);
        dynamic.setStatus(0);
        iBuildingDynamicService.update(dynamic, dynamicQueryWrapper);
        return responseBean;
    }
}
