package com.huiju.estateagents.service.impl;

import ch.qos.logback.core.status.StatusUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.DateUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaRecommendCustomer;
import com.huiju.estateagents.mapper.TaPersonMapper;
import com.huiju.estateagents.mapper.TaPersonVisitRecordMapper;
import com.huiju.estateagents.mapper.TaRecommendCustomerMapper;
import com.huiju.estateagents.service.IMiniAppService;
import com.huiju.estateagents.service.ITaRecommendCustomerService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.naming.spi.ResolveResult;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 推荐客户表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@Service
public class TaRecommendCustomerServiceImpl extends ServiceImpl<TaRecommendCustomerMapper, TaRecommendCustomer> implements ITaRecommendCustomerService {

    @Autowired
    TaPersonMapper taPersonMapper;

    @Autowired
    TaRecommendCustomerMapper taRecommendCustomerMapper;

    @Autowired
    IMiniAppService iMiniAppService;

    @Autowired
    TaPersonVisitRecordMapper taPersonVisitRecordMapper;

    @Override
    public ResponseBean getMyCustList(String openid, String keywords, int pageNumber, int pageSize) {
        List<TaPerson> taPersons = getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证当前人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }

        TaPerson taPerson = taPersons.get(0);

        IPage<TaRecommendCustomer> page = new Page<>();
        page.setCurrent(pageNumber);
        page.setSize(pageSize);

        QueryWrapper<TaRecommendCustomer> query = new QueryWrapper<>();
        query.eq("person_id", taPerson.getPersonId());
        query.like(null != keywords && "".equals(keywords.trim()), "name", keywords);
        query.orderByDesc("report_date");

        IPage<TaRecommendCustomer> result = taRecommendCustomerMapper.selectPage(page, query);
        return ResponseBean.success(result);
    }

    @Override
    public ResponseBean getCustDetail(String id) {
        TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.selectById(id);

        if (!StringUtils.isEmpty(taRecommendCustomer.getRealtyConsultant())) {
            TaPerson taPerson = taPersonMapper.selectById(taRecommendCustomer.getRealtyConsultant());
            if (null != taPerson) {
                taRecommendCustomer.setConsultants(new HashMap<String, Object>() {{
                    put("name", taPerson.getName());
                    put("phone", taPerson.getTel());
                    put("photo", taPerson.getPhoto());
                }});
            }
        }

        return ResponseBean.success(taRecommendCustomer);
    }

    @Override
    public ResponseBean updateCustByJSON(String paramStr) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (null == params) {
            return ResponseBean.error("解析参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String checkResult = checkCustomerParams(params);
        if (null != checkResult) {
            return ResponseBean.error(checkResult, ResponseBean.ERROR_MISSING_PARAMS);
        }


        UpdateWrapper<TaRecommendCustomer> wrapper = new UpdateWrapper<>();
        wrapper.eq("customer_id", params.get("id"));
        wrapper.set("name", params.get("name"));
        wrapper.set("picture", params.get("picture"));
        wrapper.set("phone", params.get("phone"));
        wrapper.set("sex", params.get("sex"));
        wrapper.set("describe", params.get("describe"));

        String at = params.getString("appointmentTime");
        if (!StringUtils.isEmpty(at)) {
            wrapper.set("appointmentTime", DateUtils.day2LocalDateime(at));
        }
        wrapper.set("vistors", params.get("vistors"));
        wrapper.set("explain", params.get("explain"));
        wrapper.set("intention", params.get("intention"));
        wrapper.set("realtyManageType", params.get("realtyManageType"));
        wrapper.set("demandType", params.get("demandType"));
        wrapper.set("priceRange", params.get("priceRange"));
        wrapper.set("realtyConsultant", params.get("realtyConsultant"));

        // todo 需要约定时间格式
//        wrapper.set("reportDate", params.get("reportDate"));

        String status = params.getString("status");
        if (null != status) {
            wrapper.set("status", params.get("status"));
        }

        int row = taRecommendCustomerMapper.update(new TaRecommendCustomer(), wrapper);
        if (row <= 0) {
            return ResponseBean.error("更新客户信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }

        return ResponseBean.success("更新客户信息成功");
    }

    @Override
    public ResponseBean recommendCust(String paramStr, String openid) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (null == params) {
            return ResponseBean.error("解析参数失败", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        List<TaPerson> taPersons = getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证当前人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson taPerson = taPersons.get(0);

        String checkResult = checkCustomerParams(params);
        if (null != checkResult) {
            return ResponseBean.error(checkResult, ResponseBean.ERROR_MISSING_PARAMS);
        }

        TaRecommendCustomer taRecommendCustomer = new TaRecommendCustomer();

        taRecommendCustomer.setName(params.getString("name"));
        taRecommendCustomer.setPicture(params.getString("picture"));
        taRecommendCustomer.setPhone(params.getString("phone"));
        taRecommendCustomer.setSex(params.getInteger("sex"));
        taRecommendCustomer.setDescribe(params.getString("describe"));
        taRecommendCustomer.setRealtyConsultant(params.getString("realtyConsultant"));

        // 时间格式 yyyy-MM-dd
        String at = params.getString("appointmentTime");
        if (!StringUtils.isEmpty(at)) {
            taRecommendCustomer.setAppointmentTime(DateUtils.day2LocalDateime(at));
        }

//        taRecommendCustomer.setAppointmentTime((String) params.get("appointmentTime"));
        taRecommendCustomer.setVisiteNum(params.getInteger("visiteNum"));
        taRecommendCustomer.setIntention(params.getString("intention"));
        taRecommendCustomer.setRealtyManageType(params.getString("realtyManageType"));
        taRecommendCustomer.setDemandType(params.getString("demandType"));
        taRecommendCustomer.setPriceRange(params.getString("priceRange"));

        // 报备日期是今天
        taRecommendCustomer.setReportDate(LocalDateTime.now());

        String status = params.getString("status");
        if (null == status) status = "1";
        taRecommendCustomer.setStatus(status);
        taRecommendCustomer.setPersonId(taPerson.getPersonId());

        // 报备有 10 天有效期
        QueryWrapper<TaRecommendCustomer> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("name", taRecommendCustomer.getName());
        queryWrapper.eq("phone", taRecommendCustomer.getPhone());
        queryWrapper.ge("report_date", LocalDateTime.now().minusDays(10));
        List<TaRecommendCustomer> result = taRecommendCustomerMapper.selectList(queryWrapper);
        if (null != result && result.size() > 0) {
            return ResponseBean.error("当前客户尚在保护期, 不能再次推荐", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        int row = taRecommendCustomerMapper.insert(taRecommendCustomer);
        if (row < 1) {
            return ResponseBean.error("推荐客户失败", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 找到销售经理，并推送消息
        TaPerson saleMan = taPersonMapper.getSalesExecutive();
        if (null != saleMan && !StringUtils.isEmpty(saleMan.getMiniOpenid())) {
            // 发送消息
            iMiniAppService.sendNewCustomerMessage(saleMan.getMiniOpenid(), CommConstant.MINIAPP_INDEX, taRecommendCustomer.getName(), taRecommendCustomer.getPhone(), "", taPerson.getName());
        }

        return ResponseBean.success(taRecommendCustomer);
    }

    String checkCustomerParams(JSONObject params) {
        if (null == params.getString("name")) {
            return "请设置客户姓名";
        }
        if (null == params.getString("phone")) {
            return "请设置客户电话";
        }
        if (null == params.getInteger("sex")) {
            return "请设置客户性别";
        }
        if (null == params.getString("intention")) {
            return "请设置意向楼盘";
        }

        return null;
    }




    List<TaPerson> getPersonsByOpenId(String openid) {
        return taPersonMapper.getPersonByOpenId(openid);
    }

    @Override
    public IPage<TaRecommendCustomer> getUnSignedCustomerList(int pageNumber, int pageSize,String building,String personId){
        QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
//        queryWrapper.eq("building_id",building);
        queryWrapper.eq("realty_consultant",personId);
        queryWrapper.gt("status", CommConstant.MESSAGE_UNREAD);
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.selectPage(page,queryWrapper);
    }

    @Override
    public IPage<TaRecommendCustomer> getCustomerList(int pageNumber, int pageSize,String building,String name,String tel,String consultName,String consultTel){
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.getCustomerList(page,building,name,tel,consultName,consultTel);
    }

    @Override
    public TaRecommendCustomer getCustomerDetail(String customerId){
        String personId = taRecommendCustomerMapper.getCustomerPersonId(customerId);
        TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.getCustomerDetail(customerId);
        if(!personId.equals("")&& null != personId){
            taRecommendCustomer.setVisitRecords(taPersonVisitRecordMapper.visitRecordByPersonId(personId));
        }
        if(!taRecommendCustomer.getRealtyConsultant().equals("")&&null != taRecommendCustomer.getRealtyConsultant()){
            TaPerson consultant =  taPersonMapper.getById(taRecommendCustomer.getRealtyConsultant());
            consultant.setProjects(taPersonMapper.getUserProjects(consultant.getPersonId()));
            taRecommendCustomer.setConsultant(consultant);
        }
        return taRecommendCustomer;
    }

    @Override
    public IPage<TaRecommendCustomer>getCustomersIRecommended(int pageNumber, int pageSize,String customerId,String building){
        String personId = taRecommendCustomerMapper.getCustomerPersonId(customerId);
        QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("person_id",personId);
//        queryWrapper.eq("building_id",building);
        queryWrapper.gt("status", CommConstant.MESSAGE_UNREAD);
        IPage<TaRecommendCustomer>page = new Page<>(pageNumber,pageSize);
        return taRecommendCustomerMapper.selectPage(page,queryWrapper);

    }
}
